# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from neurograph.v1.models.admin_users_get_many_response import AdminUsersGetManyResponse

class TestAdminUsersGetManyResponse(unittest.TestCase):
    """AdminUsersGetManyResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> AdminUsersGetManyResponse:
        """Test AdminUsersGetManyResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `AdminUsersGetManyResponse`
        """
        model = AdminUsersGetManyResponse()
        if include_optional:
            return AdminUsersGetManyResponse(
                data = [
                    neurograph.v1.models.db/user_in_db.db.UserInDb(
                        client_roles = [
                            neurograph.v1.models.db/user_client_role.db.UserClientRole(
                                client_id = '', 
                                id = 56, 
                                role_name = '', 
                                ts_created = neurograph.v1.models.pgtype/timestamp.pgtype.Timestamp(
                                    infinity_modifier = 1, 
                                    time = '', 
                                    valid = True, ), )
                            ], 
                        display_name = '', 
                        email = '', 
                        firebase_uid = '', 
                        id = 56, 
                        org_roles = [
                            neurograph.v1.models.db/user_org_role.db.UserOrgRole(
                                id = 56, 
                                org_id = '', 
                                role_name = '', )
                            ], 
                        roles = [
                            neurograph.v1.models.db/user_role.db.UserRole(
                                id = 56, 
                                role_name = '', )
                            ], 
                        ts_created = neurograph.v1.models.pgtype/timestamp.pgtype.Timestamp(
                            time = '', 
                            valid = True, ), 
                        ts_updated = , )
                    ],
                error = ''
            )
        else:
            return AdminUsersGetManyResponse(
        )
        """

    def testAdminUsersGetManyResponse(self):
        """Test AdminUsersGetManyResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from neurograph.v1.api.knowledge_api import KnowledgeApi


class TestKnowledgeApi(unittest.TestCase):
    """KnowledgeApi unit test stubs"""

    def setUp(self) -> None:
        self.api = KnowledgeApi()

    def tearDown(self) -> None:
        pass

    def test_api_v1_knowledge_assertion_client_id_entity_id_get(self) -> None:
        """Test case for api_v1_knowledge_assertion_client_id_entity_id_get

        Get Assertions by Entity
        """
        pass

    def test_api_v1_knowledge_assertion_post(self) -> None:
        """Test case for api_v1_knowledge_assertion_post

        Create Knowledge Assertion
        """
        pass

    def test_api_v1_knowledge_enrichment_artifact_client_id_artifact_id_get(self) -> None:
        """Test case for api_v1_knowledge_enrichment_artifact_client_id_artifact_id_get

        Get Enrichment Artifact
        """
        pass

    def test_api_v1_knowledge_enrichment_artifact_client_id_artifact_id_output_put(self) -> None:
        """Test case for api_v1_knowledge_enrichment_artifact_client_id_artifact_id_output_put

        Update Enrichment Artifact Output
        """
        pass

    def test_api_v1_knowledge_enrichment_artifact_client_id_artifact_id_status_put(self) -> None:
        """Test case for api_v1_knowledge_enrichment_artifact_client_id_artifact_id_status_put

        Update Enrichment Artifact Status
        """
        pass

    def test_api_v1_knowledge_enrichment_artifact_get(self) -> None:
        """Test case for api_v1_knowledge_enrichment_artifact_get

        Get Many Enrichment Artifacts
        """
        pass

    def test_api_v1_knowledge_enrichment_artifact_post(self) -> None:
        """Test case for api_v1_knowledge_enrichment_artifact_post

        Create Enrichment Artifact
        """
        pass

    def test_api_v1_knowledge_entity_get(self) -> None:
        """Test case for api_v1_knowledge_entity_get

        Get Knowledge Entities
        """
        pass

    def test_api_v1_knowledge_entity_post(self) -> None:
        """Test case for api_v1_knowledge_entity_post

        Create Knowledge Entities
        """
        pass

    def test_api_v1_knowledge_entity_upsert_post(self) -> None:
        """Test case for api_v1_knowledge_entity_upsert_post

        Bulk Uspert Entities
        """
        pass

    def test_api_v1_knowledge_extract_product_post(self) -> None:
        """Test case for api_v1_knowledge_extract_product_post

        Bulk upsert Knowledge Products
        """
        pass

    def test_api_v1_knowledge_ingest_raw_post(self) -> None:
        """Test case for api_v1_knowledge_ingest_raw_post

        Ingest raw source payloads
        """
        pass

    def test_api_v1_knowledge_kind_get(self) -> None:
        """Test case for api_v1_knowledge_kind_get

        Get Knowledge Kinds
        """
        pass

    def test_api_v1_knowledge_schema_get(self) -> None:
        """Test case for api_v1_knowledge_schema_get

        Get Knowledge Entity Schemas
        """
        pass

    def test_api_v1_knowledge_schema_post(self) -> None:
        """Test case for api_v1_knowledge_schema_post

        Upsert a Knowledge Entity Schema
        """
        pass

    def test_api_v1_knowledge_type_get(self) -> None:
        """Test case for api_v1_knowledge_type_get

        Get Knowledge Types
        """
        pass

    def test_api_v1_knowledge_type_post(self) -> None:
        """Test case for api_v1_knowledge_type_post

        Get Knowledge Types
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from neurograph.v1.models.organizations_detail_response import OrganizationsDetailResponse

class TestOrganizationsDetailResponse(unittest.TestCase):
    """OrganizationsDetailResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> OrganizationsDetailResponse:
        """Test OrganizationsDetailResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `OrganizationsDetailResponse`
        """
        model = OrganizationsDetailResponse()
        if include_optional:
            return OrganizationsDetailResponse(
                branding = neurograph.v1.models.organizations/brand.organizations.Brand(
                    background_img_url = '', 
                    color1 = '', 
                    color2 = '', 
                    color3 = '', 
                    color4 = '', 
                    color5 = '', 
                    id = 56, 
                    logo_img_url = '', 
                    primary_color = '', 
                    secondary_color = '', 
                    tertiary_color = '', ),
                description = '',
                error = '',
                id = 'org_123',
                image_url = '',
                is_active = True,
                name = '',
                ts_created = 56,
                ts_updated = 56,
                uid = '',
                url = '',
                workbench = neurograph.v1.models.organizations/workbench_config.organizations.WorkbenchConfig(
                    description = '', 
                    org_id = 'org_123', 
                    version = '', 
                    version_name = '', 
                    workbench_is_active = True, 
                    workbench_url = '', 
                    workbench_url_ext = '', )
            )
        else:
            return OrganizationsDetailResponse(
        )
        """

    def testOrganizationsDetailResponse(self):
        """Test OrganizationsDetailResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from neurograph.v1.models.client_get_detail_response import ClientGetDetailResponse

class TestClientGetDetailResponse(unittest.TestCase):
    """ClientGetDetailResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ClientGetDetailResponse:
        """Test ClientGetDetailResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ClientGetDetailResponse`
        """
        model = ClientGetDetailResponse()
        if include_optional:
            return ClientGetDetailResponse(
                data = neurograph.v1.models.client/client.client.Client(
                    id = '', 
                    is_active = True, 
                    name = '', 
                    org_id = '', 
                    ts_created = 56, 
                    ts_updated = 56, 
                    uid = '', 
                    urls = [
                        neurograph.v1.models.db/client_url.db.ClientUrl(
                            client_id = 'cli_12345', 
                            customer_environment = '', 
                            id = 56, 
                            is_active = True, 
                            url = 'example.com', )
                        ], ),
                error = ''
            )
        else:
            return ClientGetDetailResponse(
        )
        """

    def testClientGetDetailResponse(self):
        """Test ClientGetDetailResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from neurograph.v1.models.db_my_org import DbMyOrg

class TestDbMyOrg(unittest.TestCase):
    """DbMyOrg unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> DbMyOrg:
        """Test DbMyOrg
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `DbMyOrg`
        """
        model = DbMyOrg()
        if include_optional:
            return DbMyOrg(
                brand = neurograph.v1.models.db/account_organization_brand.db.AccountOrganizationBrand(
                    background_img_url = '', 
                    color1 = '', 
                    color2 = '', 
                    color3 = '', 
                    color4 = '', 
                    color5 = '', 
                    id = 56, 
                    logo_img_url = '', 
                    org_id = '', 
                    primary_color = '', 
                    secondary_color = '', 
                    tertiary_color = '', ),
                description = '',
                id = '',
                image_url = '',
                is_active = True,
                name = '',
                roles = [
                    neurograph.v1.models.db/user_org_role.db.UserOrgRole(
                        id = 56, 
                        org_id = '', 
                        role_name = '', 
                        ts_created = neurograph.v1.models.pgtype/timestamp.pgtype.Timestamp(
                            infinity_modifier = 1, 
                            time = '', 
                            valid = True, ), )
                    ],
                url = '',
                workbench_is_active = True,
                workbench_url = '',
                workbench_url_ext = '',
                workbench_version_id = ''
            )
        else:
            return DbMyOrg(
        )
        """

    def testDbMyOrg(self):
        """Test DbMyOrg"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from neurograph.v1.models.knowledge_order_query import KnowledgeOrderQuery

class TestKnowledgeOrderQuery(unittest.TestCase):
    """KnowledgeOrderQuery unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> KnowledgeOrderQuery:
        """Test KnowledgeOrderQuery
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `KnowledgeOrderQuery`
        """
        model = KnowledgeOrderQuery()
        if include_optional:
            return KnowledgeOrderQuery(
                billing_address_hash = '',
                channel = '',
                client_id = '',
                currency = '',
                customer_entity_id = '',
                email_at_order = '',
                ext_order_id = '',
                ext_order_number = '',
                ext_store_id = '',
                financial_status = '',
                fulfillment_status = '',
                limit = 56,
                offset = 56,
                phone_at_order = '',
                placed_from = '',
                placed_to = '',
                shipping_address_hash = '',
                source_name = '',
                status = '',
                store_entity_id = '',
                total_max = '',
                total_min = ''
            )
        else:
            return KnowledgeOrderQuery(
        )
        """

    def testKnowledgeOrderQuery(self):
        """Test KnowledgeOrderQuery"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from neurograph.v1.models.organizations_get_many_response import OrganizationsGetManyResponse

class TestOrganizationsGetManyResponse(unittest.TestCase):
    """OrganizationsGetManyResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> OrganizationsGetManyResponse:
        """Test OrganizationsGetManyResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `OrganizationsGetManyResponse`
        """
        model = OrganizationsGetManyResponse()
        if include_optional:
            return OrganizationsGetManyResponse(
                data = [
                    neurograph.v1.models.organizations/organization.organizations.Organization(
                        description = '', 
                        id = 'org_123', 
                        image_url = '', 
                        is_active = True, 
                        name = '', 
                        ts_created = 56, 
                        ts_updated = 56, 
                        uid = '', 
                        url = '', )
                    ],
                error = '',
                limit = 56,
                offset = 56,
                total_rows = 56
            )
        else:
            return OrganizationsGetManyResponse(
        )
        """

    def testOrganizationsGetManyResponse(self):
        """Test OrganizationsGetManyResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from neurograph.v1.models.personas_instance_create_request import PersonasInstanceCreateRequest

class TestPersonasInstanceCreateRequest(unittest.TestCase):
    """PersonasInstanceCreateRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> PersonasInstanceCreateRequest:
        """Test PersonasInstanceCreateRequest
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `PersonasInstanceCreateRequest`
        """
        model = PersonasInstanceCreateRequest()
        if include_optional:
            return PersonasInstanceCreateRequest(
                age = 1.337,
                description = '',
                female = 1.337,
                income = '',
                male = 1.337,
                metadata = '',
                name = '',
                persona_seed_id = '',
                personality_background = '',
                personality_first_name = '',
                personality_img_url = '',
                personality_last_name = '',
                personality_quote = '',
                personality_video_url = '',
                positioning_statement = '',
                summary_detail = '',
                summary_headline = '',
                tag = '',
                value = ''
            )
        else:
            return PersonasInstanceCreateRequest(
        )
        """

    def testPersonasInstanceCreateRequest(self):
        """Test PersonasInstanceCreateRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from neurograph.v1.models.knowledge_enrichment_artifact import KnowledgeEnrichmentArtifact

class TestKnowledgeEnrichmentArtifact(unittest.TestCase):
    """KnowledgeEnrichmentArtifact unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> KnowledgeEnrichmentArtifact:
        """Test KnowledgeEnrichmentArtifact
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `KnowledgeEnrichmentArtifact`
        """
        model = KnowledgeEnrichmentArtifact()
        if include_optional:
            return KnowledgeEnrichmentArtifact(
                agent_engine_run_id = '',
                artifact_id = 56,
                attempt_count = 56,
                client_id = '',
                cloud_run_execution_id = '',
                cloud_run_job_name = '',
                completed_at = '',
                confidence = 1.337,
                config_entity_id = '',
                config_snapshot = None,
                created_at = '',
                input_params = None,
                is_current = True,
                job_name = '',
                last_error = '',
                output_json = None,
                output_schema_id = '',
                output_text = '',
                queued_at = '',
                spec_version = 56,
                started_at = '',
                status = '',
                subject_entity_id = '',
                supersedes_artifact_id = 56,
                task_name = '',
                task_queue_name = ''
            )
        else:
            return KnowledgeEnrichmentArtifact(
        )
        """

    def testKnowledgeEnrichmentArtifact(self):
        """Test KnowledgeEnrichmentArtifact"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from neurograph.v1.models.knowledge_enrichment_artifact_list_response import KnowledgeEnrichmentArtifactListResponse

class TestKnowledgeEnrichmentArtifactListResponse(unittest.TestCase):
    """KnowledgeEnrichmentArtifactListResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> KnowledgeEnrichmentArtifactListResponse:
        """Test KnowledgeEnrichmentArtifactListResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `KnowledgeEnrichmentArtifactListResponse`
        """
        model = KnowledgeEnrichmentArtifactListResponse()
        if include_optional:
            return KnowledgeEnrichmentArtifactListResponse(
                data = [
                    neurograph.v1.models.knowledge/enrichment_artifact.knowledge.EnrichmentArtifact(
                        agent_engine_run_id = '', 
                        artifact_id = 56, 
                        attempt_count = 56, 
                        client_id = '', 
                        cloud_run_execution_id = '', 
                        cloud_run_job_name = '', 
                        completed_at = '', 
                        confidence = 1.337, 
                        config_entity_id = '', 
                        config_snapshot = neurograph.v1.models.config_snapshot.config_snapshot(), 
                        created_at = '', 
                        input_params = neurograph.v1.models.input_params.input_params(), 
                        is_current = True, 
                        job_name = '', 
                        last_error = '', 
                        output_json = neurograph.v1.models.output_json.output_json(), 
                        output_schema_id = '', 
                        output_text = '', 
                        queued_at = '', 
                        spec_version = 56, 
                        started_at = '', 
                        status = '', 
                        subject_entity_id = '', 
                        supersedes_artifact_id = 56, 
                        task_name = '', 
                        task_queue_name = '', )
                    ],
                error = '',
                query = neurograph.v1.models.knowledge/enrichment_query.knowledge.EnrichmentQuery(
                    client_id = '', 
                    is_current = True, 
                    job_name = '', 
                    kind = '', 
                    limit = 56, 
                    offset = 56, 
                    status = '', 
                    subject_entity_id = '', )
            )
        else:
            return KnowledgeEnrichmentArtifactListResponse(
        )
        """

    def testKnowledgeEnrichmentArtifactListResponse(self):
        """Test KnowledgeEnrichmentArtifactListResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from neurograph.v1.api.client_api import ClientApi


class TestClientApi(unittest.TestCase):
    """ClientApi unit test stubs"""

    def setUp(self) -> None:
        self.api = ClientApi()

    def tearDown(self) -> None:
        pass

    def test_api_v1_client_personas_client_id_get(self) -> None:
        """Test case for api_v1_client_personas_client_id_get

        Get Client's Personas
        """
        pass

    def test_api_v1_client_url_client_id_get(self) -> None:
        """Test case for api_v1_client_url_client_id_get

        Get client's URLs
        """
        pass

    def test_api_v1_client_url_post(self) -> None:
        """Test case for api_v1_client_url_post

        Upsert a Client Url
        """
        pass

    def test_api_v1_client_url_probe_client_id_post(self) -> None:
        """Test case for api_v1_client_url_probe_client_id_post

        Trigger client URL probes
        """
        pass

    def test_api_v1_client_url_snapshot_probe_id_get(self) -> None:
        """Test case for api_v1_client_url_snapshot_probe_id_get

        Get a client's URL snapshot by probe id
        """
        pass

    def test_api_v1_clients_client_id_get(self) -> None:
        """Test case for api_v1_clients_client_id_get

        Get Client by ID
        """
        pass

    def test_api_v1_clients_client_id_users_get(self) -> None:
        """Test case for api_v1_clients_client_id_users_get

        Client's assigned users and their permissions
        """
        pass

    def test_api_v1_clients_get(self) -> None:
        """Test case for api_v1_clients_get

        Get Clients
        """
        pass

    def test_api_v1_clients_post(self) -> None:
        """Test case for api_v1_clients_post

        Upsert a Client
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from neurograph.v1.models.client_metadata_response import ClientMetadataResponse

class TestClientMetadataResponse(unittest.TestCase):
    """ClientMetadataResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ClientMetadataResponse:
        """Test ClientMetadataResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ClientMetadataResponse`
        """
        model = ClientMetadataResponse()
        if include_optional:
            return ClientMetadataResponse(
                client = neurograph.v1.models.client/info.client.Info(
                    id = '', 
                    is_active = True, 
                    name = '', 
                    org_id = '', 
                    ts_created = 56, 
                    ts_updated = 56, 
                    uid = '', ),
                error = '',
                metadata = [
                    neurograph.v1.models.client/metadata.client.Metadata(
                        key = '', 
                        ts_created = 56, 
                        ts_updated = 56, 
                        value = '', )
                    ],
                organization = neurograph.v1.models.client/organization_detail.client.OrganizationDetail(
                    branding = neurograph.v1.models.client/organization_brand.client.OrganizationBrand(
                        background_img_url = '', 
                        color1 = '', 
                        color2 = '', 
                        color3 = '', 
                        color4 = '', 
                        color5 = '', 
                        id = '', 
                        logo_img_url = '', 
                        primary_color = '', 
                        secondary_color = '', 
                        tertiary_color = '', ), 
                    description = '', 
                    id = '', 
                    image_url = '', 
                    is_active = True, 
                    name = '', 
                    ts_created = 56, 
                    ts_updated = 56, 
                    uid = '', 
                    url = '', 
                    workbench = neurograph.v1.models.client/workbench_config.client.WorkbenchConfig(
                        description = '', 
                        org_id = '', 
                        version = '', 
                        version_name = '', 
                        workbench_is_active = True, 
                        workbench_url = '', 
                        workbench_url_ext = '', ), )
            )
        else:
            return ClientMetadataResponse(
        )
        """

    def testClientMetadataResponse(self):
        """Test ClientMetadataResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
